package vip.xiaonuo.modular.people.controller;/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.interceptor.TransactionAspectSupport;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.common.pojo.CommonValidList;
import vip.xiaonuo.modular.people.entity.PeopleList;
import vip.xiaonuo.modular.people.param.PeopleListAddParam;
import vip.xiaonuo.modular.people.param.PeopleListEditParam;
import vip.xiaonuo.modular.people.param.PeopleListIdParam;
import vip.xiaonuo.modular.people.param.PeopleListPageParam;
import vip.xiaonuo.modular.people.service.PeopleListService;
import vip.xiaonuo.modular.people.utils.UploadImage;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.io.IOException;

/**
 * people_list控制器
 *
 * @author wang
 * @date  2023/12/04 16:16
 */
@Api(tags = "people_list控制器")
@ApiSupport(author = "SNOWY_TEAM", order = 1)
@RestController
@Validated
public class PeopleListController {

    @Resource
    private PeopleListService peopleListService;
    @Resource
    private UploadImage uploadImage;


    /**
     * 获取people_list分页
     *
     * @author wang
     * @date  2023/12/04 16:16
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取people_list分页")
    @GetMapping("/biz/nongke/page")
    public CommonResult<Page<PeopleList>> page(PeopleListPageParam peopleListPageParam) {
        return CommonResult.data(peopleListService.page(peopleListPageParam));
    }

    /**
     * 添加people_list
     *
     * @author wang
     * @date 2023/12/04 16:16
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加people_list")
    @CommonLog("添加people_list")
    @PostMapping("/biz/nongke/add")
    public CommonResult<String> add(@RequestParam(name = "userName") String userName,
                                    @RequestParam(name = "nickName") String nickName,
                                    @RequestParam(name = "sex") Integer sex,
                                    @RequestParam(name = "phone") String phone,
                                    @RequestParam(name = "img") MultipartFile img,
                                    @RequestParam(name = "manageArea") String manageArea,
                                    @RequestParam(name = "orgId") String orgId) throws IOException {
        PeopleListAddParam peopleListAddParam = new PeopleListAddParam();
        String imageCom = "";
        if (ObjectUtil.isNotEmpty(img)) {
            if (uploadImage.getImageCom(img).equals("上传失败")) {
                TransactionAspectSupport.currentTransactionStatus().setRollbackOnly();
                return new CommonResult(500, "图片上传失败", false);
            }
            imageCom = uploadImage.getImageCom(img);
            peopleListAddParam.setImg(imageCom);
        }
        peopleListAddParam.setUserName(userName);
        peopleListAddParam.setManageArea(manageArea);
        peopleListAddParam.setSex(sex);
        peopleListAddParam.setPhone(phone);
        peopleListAddParam.setNickName(nickName);
        peopleListAddParam.setOrgId(orgId);
        return peopleListService.add(peopleListAddParam);
    }

    /**
     * 编辑people_list
     *
     * @author wang
     * @date  2023/12/04 16:16
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑people_list")
    @CommonLog("编辑people_list")
    @PostMapping("/biz/nongke/edit")
    public CommonResult<String> edit(@RequestBody @Valid PeopleListEditParam peopleListEditParam) {
        return peopleListService.edit(peopleListEditParam);
    }

    /**
     * 删除people_list
     *
     * @author wang
     * @date  2023/12/04 16:16
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除people_list")
    @CommonLog("删除people_list")
    @PostMapping("/biz/nongke/delete")
    public CommonResult<String> delete(@RequestBody @NotEmpty(message = "集合不能为空")
                                               CommonValidList<PeopleListIdParam> peopleListIdParamList) {
        peopleListService.delete(peopleListIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取people_list详情
     *
     * @author wang
     * @date  2023/12/04 16:16
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取people_list详情")
    @GetMapping("/biz/nongke/detail")
    public CommonResult<PeopleList> detail(@Valid PeopleListIdParam peopleListIdParam) {
        return CommonResult.data(peopleListService.detail(peopleListIdParam));
    }
}
